<?php

/*
 * LMS version 1.7.4 Wraith
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: domaindel.php,v 1.6 2005/05/26 13:24:57 alec Exp $
 */

$id = $_GET['id'];

if($id && $_GET['is_sure']=='1')
{
	if($DB->Execute('DELETE FROM domains WHERE id = ?', array($id)))
	{
		$LMS->SetTS('domains');
		if($accounts = $DB->GetCol('SELECT id FROM passwd WHERE domainid = ?', array($id)))
		{
			foreach($accounts as $aid)
				$DB->Execute('DELETE FROM aliases WHERE accountid = ?', array($aid));
		
			$DB->Execute('DELETE FROM passwd WHERE domainid = ?', array($id));
			$LMS->SetTS('passwd');
			$LMS->SetTS('aliases');
		}
	}
}

header('Location: ?m=domainlist');

?>
